#
# spec file for package python-opengl
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define tarname PyOpenGL
Name:           python-opengl
Version:        3.1.1a1
Release:        lp150.1.3
Summary:        OpenGL bindings for Python
License:        BSD-3-Clause
Group:          Development/Libraries/Python
Url:            http://pyopengl.sourceforge.net
Source0:        https://files.pythonhosted.org/packages/source/P/%{tarname}/%{tarname}-%{version}.tar.gz
Source1:        %{name}.changes
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  libdrm-devel
BuildRequires:  libgle-devel
BuildRequires:  python-rpm-macros
BuildRequires:  swig
BuildRequires:  tk-devel
BuildRequires:  xorg-x11
Requires:       python-numpy
Requires:       tk >= 8.1
Recommends:     python-opengl-accelerate
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
OpenGL bindings for Python including support for GL extensions, GLU,
WGL, GLUT, GLE, and Tk.

%prep
%setup -q -n %{tarname}-%{version}
# remove shebang
sed -e '1d' -i OpenGL/arrays/_buffers.py OpenGL/arrays/buffers.py
# avoid "python-bytecode-inconsistent-mtime" warning
FAKE_TIMESTAMP=$(LC_ALL=C date -u -r %{SOURCE1} +%%y%%m%%d%%H%%M)
find . -name '*.py' -exec touch -mat $FAKE_TIMESTAMP {} \;

%build
export CFLAGS="%{optflags} -DGLX_GLXEXT_LEGACY"
%python_build

%install
%python_install
%python_expand %fdupes -s %{buildroot}%{$python_sitelib}/OpenGL/

%files %{python_files}
%defattr(-,root,root)
%doc license.txt
%{python_sitelib}/OpenGL/
%{python_sitelib}/PyOpenGL-%{version}-py%{python_version}.egg-info

%changelog
* Mon Jun  5 2017 aloisio@gmx.com
- Update to version 3.1.1a1
- Added python-opengl.changes as source
- Converted to single-spec
* Mon Jul 14 2014 toddrme2178@gmail.com
- Update to 3.1.0
  * no changelog
* Fri Apr 19 2013 toddrme2178@gmail.com
- Update to 3.0.2
  * no changelog
- Add python 3 version
* Tue Sep 14 2010 coolo@novell.com
- update to 3.0.1
  * tons of changes, but no upstream documentation beside
    ChangeLog.txt
* Tue Aug 11 2009 matejcik@suse.cz
- removed non-applied patches
- switched to noarch (accelerator is not present, so no
  platform-dependent parts)
* Thu Aug  6 2009 matejcik@suse.cz
- update to 3.0.0
  * big under-the-hood rewrite while using backwards-compatible API
  * support for entire OGL3.0 api and most extensions
  * plug-in API
  * lower performance (accelerator module is not done yet)
  * package-level configuration flags
* Wed Jun 10 2009 ro@suse.de
- buildreq: replace gle by libgle-devel for >= 11.2
* Mon May  4 2009 ro@suse.de
- buildrequires: replace python-numeric by python-numpy
  for >= 11.2
* Fri Jan 26 2007 jmatejek@suse.cz
- removed strict-aliasing warnings
- removed invalid operations
* Tue Nov 21 2006 prusnak@suse.cz
- changes according to PEP353 (pep353.diff)
* Mon Sep 11 2006 jmatejek@suse.cz
- replaced a mistyped unicode nonbreakspace with a
  regular space, thus fixing build with python2.5
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 jmatejek@suse.cz
- added build dependency on tk-devel
- fixed build not to require X server
* Mon Jun 20 2005 ltinkl@suse.cz
- added freeglut* packages to fix dependencies (#80605), plus
  optional (but recommended) dependency on python-imaging (pil)
* Tue Nov 23 2004 mcihar@suse.cz
- update to 2.0.1.09
- simplified filelist generating
* Wed Aug  4 2004 mcihar@suse.cz
- update to 2.0.1.08
* Wed Apr 21 2004 mcihar@suse.cz
- fix gcc warning
- fixed python requires
- use sed instead of patch for lib64
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Mon Jun 16 2003 mcihar@suse.cz
- added some magic to generate correct filelist
* Mon Jun  9 2003 mcihar@suse.cz
- documentation isn't executable
* Thu Jun  5 2003 mcihar@suse.cz
- rather move documentation than symlink, as otherwise upgrade
  doesn't work correctly
* Tue May 27 2003 mcihar@suse.cz
- install documentation only once
* Fri Jan 10 2003 mcihar@suse.cz
- fixed build for lib64 arches
* Mon Jan  6 2003 mcihar@suse.cz
- initial package version
